from random import choice

List = [
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 211.0.0.21.118 (iPhone12,8; iOS 14_8; en_CL; en-CL; scale=2.00; 750x1334; 327311214)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 210.0.0.16.67 (iPhone11,8; iOS 15_0_1; es_CL; es-CL; scale=2.00; 828x1792; 325544617)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone13,1; iOS 14_7_1; en_SA@calendar=gregorian; en-SA; scale=2.88; 1080x2338; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone13,1; iOS 14_7_1; en_SA@calendar=gregorian; en-SA; scale=2.88; 1080x2338; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone14,2; iOS 15_1; da_DK; da-DK; scale=3.00; 1170x2532; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,1; iOS 14_8; pt_BR; pt-BR; scale=2.00; 828x1792; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone12,3; iOS 14_7_1; ru_RU; ru-RU; scale=3.00; 1125x2436; 329643252) NW/1",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,4; iOS 15_1; it_IT; it; scale=3.00; 1284x2778; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,1; iOS 15_0_2; ru_RU; ru; scale=2.88; 1080x2338; 330663239)",
    "Mozilla/5.0 (iPad; CPU OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPad8,9; iPadOS 15_1; en_IT; en-GB; scale=2.00; 750x1334; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 13_5_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 208.0.0.26.131 (iPhone12,3; iOS 13_5_1; ru_RU; ru-RU; scale=3.00; 1125x2436; 322184766) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 13_5_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 208.0.0.26.131 (iPhone12,3; iOS 13_5_1; ru_RU; ru-RU; scale=3.00; 1125x2436; 322184766)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,3; iOS 14_8_1; ru_RU; ru-RU; scale=3.00; 1170x2532; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,3; iOS 14_8_1; ru_RU; ru-RU; scale=3.00; 1170x2532; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,2; iOS 15_0; ru_RU; ru-RU; scale=3.00; 1170x2532; 330663239) NW/1",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone9,1; iOS 14_8_1; it_IT; it-IT; scale=2.00; 750x1334; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,1; iOS 14_7_1; it_IT; it-IT; scale=2.00; 828x1792; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 13_6 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 208.0.0.26.131 (iPhone9,3; iOS 13_6; ru_RU; ru-RU; scale=2.00; 750x1334; 322184766) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,1; iOS 15_1; it_IT; it-IT; scale=2.00; 828x1792; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,1; iOS 15_1; it_IT; it-IT; scale=2.00; 828x1792; 330663239) NW/1",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone11,8; iOS 15_0_2; it_IT; it-IT; scale=2.00; 828x1792; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone9,1; iOS 14_7_1; ru_RU; ru-RU; scale=2.00; 750x1334; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 211.0.0.21.118 (iPhone9,4; iOS 15_1; ru_RU; ru-RU; scale=2.61; 1080x1920; 327311214)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 211.0.0.21.118 (iPhone9,4; iOS 15_1; ru_RU; ru-RU; scale=2.61; 1080x1920; 327311214) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,2; iOS 15_0; ru_RU; ru-RU; scale=3.00; 1170x2532; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,2; iOS 15_0; ru_RU; ru-RU; scale=3.00; 1170x2532; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone10,4; iOS 15_0_2; ru_RU; ru-RU; scale=2.00; 750x1334; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone10,4; iOS 15_0_2; ru_RU; ru-RU; scale=2.00; 750x1334; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,1; iOS 14_8; ru_RU; ru-RU; scale=2.00; 828x1792; 330663239) NW/1",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,1; iOS 14_8; ru_RU; ru-RU; scale=2.00; 828x1792; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,1; iOS 14_8; ru_RU; ru-RU; scale=2.00; 828x1792; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 210.0.0.16.67 (iPhone9,3; iOS 15_0_1; ru_RU; ru-RU; scale=2.00; 750x1334; 325544617) NW/1",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 210.0.0.16.67 (iPhone9,3; iOS 15_0_1; ru_RU; ru-RU; scale=2.00; 750x1334; 325544617) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,1; iOS 15_0_2; ru_RU; ru-RU; scale=2.00; 828x1792; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 210.0.0.16.67 (iPhone9,3; iOS 15_0_1; ru_RU; ru-RU; scale=2.00; 750x1334; 325544617)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,1; iOS 15_0_2; ru_RU; ru-RU; scale=2.00; 828x1792; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 13_6 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 208.0.0.26.131 (iPhone9,3; iOS 13_6; ru_RU; ru-RU; scale=2.00; 750x1334; 322184766)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 210.0.0.16.67 (iPhone8,1; iOS 15_1; ru_RU; ru-RU; scale=2.00; 750x1334; 325544617)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,3; iOS 15_1; en_IT; en-IT; scale=3.00; 1125x2436; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 211.0.0.21.118 (iPhone8,1; iOS 15_0; ru_RU; ru-RU; scale=2.00; 750x1334; 327311214)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,3; iOS 14_8; ru_AT; ru-AT; scale=3.00; 1170x2532; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,3; iOS 14_8; ru_AT; ru-AT; scale=3.00; 1170x2532; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone11,8; iOS 15_1; it_GB; it-GB; scale=2.00; 828x1792; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,1; iOS 14_8_1; it_IT; it-IT; scale=2.00; 828x1792; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 123.0.0.24.115 (iPhone10,4; iOS 14_8; en_IT; en-GB; scale=2.00; 750x1334; 188362626)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone10,5; iOS 15_0_2; it_IT; it-IT; scale=2.61; 1080x1920; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone11,8; iOS 14_8_1; ru_RU; ru-RU; scale=2.00; 828x1792; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,1; iOS 14_8_1; it_IT; it-IT; scale=2.00; 828x1792; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone9,3; iOS 14_7_1; it_IT; it-IT; scale=2.00; 750x1334; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone14,3; iOS 15_0_2; it_IT; it-IT; scale=3.00; 1284x2778; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,3; iOS 15_0_2; it_IT; it-IT; scale=3.00; 1170x2532; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,1; iOS 14_7_1; ru_RU; ru-RU; scale=2.00; 750x1334; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_4_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 207.0.0.28.118 (iPhone8,1; iOS 14_4_1; ru_RU; ru-RU; scale=2.00; 750x1334; 320361397)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,1; iOS 14_7_1; ru_RU; ru-RU; scale=2.00; 750x1334; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_4_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 211.0.0.21.118 (iPhone13,4; iOS 14_4_2; ru_RU; ru-RU; scale=3.00; 1284x2778; 327311214) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,3; iOS 14_7_1; ru_RU; ru-RU; scale=3.00; 1170x2532; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone13,3; iOS 15_0_2; it_IT; it-IT; scale=3.00; 1170x2532; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone9,3; iOS 14_8_1; ru_RU; ru-RU; scale=2.00; 750x1334; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone11,8; iOS 15_0_2; it_IT; it-IT; scale=2.00; 828x1792; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_6 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 206.0.0.30.118 (iPhone13,2; iOS 14_6; it_IT; it-IT; scale=3.00; 1170x2532; 318760365)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone12,5; iOS 15_0_2; ru_RU; ru-RU; scale=3.00; 1242x2688; 330663239)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone11,2; iOS 15_1; it_IT; it-IT; scale=3.00; 1125x2436; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone8,1; iOS 14_2; it_IT; it-IT; scale=2.00; 750x1334; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone13,2; iOS 14_8; en_US; en-US; scale=3.66; 1170x2533; 329643252) NW/1",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone13,2; iOS 14_8; en_US; en-US; scale=3.66; 1170x2533; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 211.0.0.21.118 (iPhone12,1; iOS 14_8; pt_BR; pt-BR; scale=2.00; 828x1792; 327311214)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 209.1.0.25.113 (iPhone9,4; iOS 14_8_1; ru_RU; ru-RU; scale=2.61; 1080x1920; 324511477)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 211.0.0.21.118 (iPhone9,3; iOS 14_8; ru_RU; ru-RU; scale=2.00; 750x1334; 327311214)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,3; iOS 15_0_2; it_IT; it-IT; scale=2.00; 750x1334; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 211.0.0.21.118 (iPhone11,8; iOS 14_7_1; it_IT; it-IT; scale=2.00; 828x1792; 327311214)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,2; iOS 15_0_2; ru_RU; ru-RU; scale=2.61; 1080x1920; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 211.0.0.21.118 (iPhone12,1; iOS 14_7_1; it_IT; it-IT; scale=2.00; 828x1792; 327311214)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_6 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone10,5; iOS 14_6; it_IT; it-IT; scale=2.61; 1080x1920; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone13,2; iOS 15_0_2; it_IT; it-IT; scale=3.00; 1170x2532; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_4 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone8,1; iOS 14_4; it_IT; it-IT; scale=2.00; 750x1334; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone11,8; iOS 14_8_1; it_IT; it-IT; scale=2.00; 828x1792; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone12,1; iOS 15_0_2; en_IT; en-IT; scale=2.21; 828x1792; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 213.0.0.19.117 (iPhone10,5; iOS 14_8_1; pt_AL; pt-AL; scale=2.88; 1080x1920; 330663239) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,3; iOS 15_1; it_IT; it-IT; scale=2.00; 750x1334; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone10,5; iOS 14_8_1; ru_RU; ru-RU; scale=2.61; 1080x1920; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone10,5; iOS 14_8_1; ru_RU; ru-RU; scale=2.61; 1080x1920; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,3; iOS 14_3; ru_RU; ru-RU; scale=2.00; 750x1334; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,3; iOS 15_0_1; ru_RU; ru-RU; scale=2.00; 750x1334; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone10,6; iOS 15_1; it_IT; it-IT; scale=3.00; 1125x2436; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 211.0.0.21.118 (iPhone9,3; iOS 14_7_1; ru_KZ; ru-KZ; scale=2.00; 750x1334; 327311214)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone12,1; iOS 15_2; ru_RU; ru-RU; scale=2.00; 828x1792; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone11,2; iOS 14_7_1; ru_RU; ru-RU; scale=3.00; 1125x2436; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,2; iOS 15_0_2; ru_RU; ru-RU; scale=2.61; 1080x1920; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone11,8; iOS 15_1; es_AR; es-AR; scale=2.21; 828x1792; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone12,1; iOS 14_8_1; en_GB; en-GB; scale=2.00; 828x1792; 329643252) NW/1",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,3; iOS 14_7_1; ru_RU; ru-RU; scale=2.00; 750x1334; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,3; iOS 14_7_1; ru_RU; ru-RU; scale=2.00; 750x1334; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone13,2; iOS 14_7_1; it_IT; it; scale=3.00; 1170x2532; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,4; iOS 15_0_2; ru_RU; ru-RU; scale=2.88; 1080x1920; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,4; iOS 15_0_2; ru_RU; ru-RU; scale=2.88; 1080x1920; 329643252)",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone12,1; iOS 14_8_1; en_GB; en-GB; scale=2.00; 828x1792; 329643252) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 15_0_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 211.0.0.21.118 (iPhone10,4; iOS 15_0_2; it_IT; it-IT; scale=2.00; 750x1334; 327311214) NW/3",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_4_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone9,3; iOS 14_4_2; it_IT; it-IT; scale=2.00; 750x1334; 329643252)",
    "Mozilla/5.0 (iPad; CPU OS 14_8_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPad7,2; iOS 14_8_1; it_IT; it-IT; scale=2.00; 1334x750; 329643252) NW/1",
    "Mozilla/5.0 (iPhone; CPU iPhone OS 14_7_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Mobile/15E148 Instagram 212.1.0.25.118 (iPhone10,4; iOS 14_7_1; it_IT; it-IT; scale=2.00; 750x1334; 329643252)"
]

def agent():
    return choice(List)